package com.gic.cloud.operation.web.controller;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.DataExplainDTO;
import com.gic.cloud.dto.IndexLogDTO;
import com.gic.cloud.qo.DataExplainQO;
import com.gic.cloud.service.DataExplainApiService;
import com.gic.cloud.service.IndexLogApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.ResultControllerUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author zhiwj
 * @Description:
 * @date 2020-07-09 17:20
 */
@RestController
public class DataExplainController {

    @Autowired
    private DataExplainApiService dataExplainApiService;
    @Autowired
    private IndexLogApiService indexLogApiService;

    @RequestMapping("/saveDataExplain")
    public RestResponse saveDataExplain(DataExplainDTO dataExplainDTO) {
        if (StringUtils.isBlank(dataExplainDTO.getDataName()) || StringUtils.isBlank(dataExplainDTO.getIndexRemark())) {
            return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), ErrorCode.PARAMETER_ERROR.getMsg());
        }
        ServiceResponse<Void> serviceResponse = dataExplainApiService.saveDataExplain(dataExplainDTO);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/updateDataExplain")
    public RestResponse updateDataExplain(DataExplainDTO dataExplainDTO, Integer updateType, String reason) {
        ServiceResponse<Void> serviceResponse = dataExplainApiService.updateDataExplain(dataExplainDTO, updateType, reason);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/getByDataExplainId")
    public RestResponse getByDataExplainId(Integer dataExplainId) {
        ServiceResponse<DataExplainDTO> serviceResponse = dataExplainApiService.getByDataExplainId(dataExplainId);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/listDataExplain")
    public RestResponse listDataExplain(DataExplainQO dataExplainQO) {
        ServiceResponse<Page<DataExplainDTO>> serviceResponse = dataExplainApiService.listDataExplain(dataExplainQO);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/dataExplainLog")
    public RestResponse dataExplainLog(Integer dataExplainId) {
        ServiceResponse<List<IndexLogDTO>> serviceResponse = indexLogApiService.listDataExplainLog(dataExplainId);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/deleteDataExplain")
    public RestResponse delete(Integer dataExplainId) {
        ServiceResponse<Void> serviceResponse = dataExplainApiService.delete(dataExplainId);
        return ResultControllerUtils.commonResult(serviceResponse);
    }

    @RequestMapping("/publishDataExplain")
    public RestResponse publishIndex(String dataExplainIds) {
        if (StringUtils.isBlank(dataExplainIds)) {
            return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), ErrorCode.PARAMETER_ERROR.getMsg());
        }
        ServiceResponse<Void> serviceResponse = dataExplainApiService.publish(Stream.of(dataExplainIds.split(",")).map(Integer::valueOf).collect(Collectors.toList()));
        return ResultControllerUtils.commonResult(serviceResponse);
    }

}