package com.gic.cloud.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.UserDTO;
import com.gic.cloud.service.UserApiService;
import com.gic.cloud.web.constant.ErrorCode;
import com.gic.cloud.web.vo.LoginUserVo;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.utils.CreateRandomUtils;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.marketing.process.api.service.sms.SmsSendApiService;
import com.gic.redis.data.util.RedisUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.concurrent.TimeUnit;

@RestController
public class LoginController {
    private static final Logger log = LogManager.getLogger(LoginController.class);

    @Autowired
    private UserApiService userApiService;
    @Autowired
    private SmsSendApiService smsSendApiService;

    @RequestMapping("send-code")
    public RestResponse sendCode(String phoneNumber, String areaCode){
        String smsSenceId = "GYT0001";
        List<UserDTO> userDTOList = this.userApiService.listUserByPhone("86", phoneNumber).getResult();
        if(CollectionUtils.isNotEmpty(userDTOList)){
            Integer enterpriseId = userDTOList.get(0).getEnterpriseId();
            String code = CreateRandomUtils.getStringRandom(4);
            ServiceResponse<Void> smsSendResult = smsSendApiService.sendPlatformSms(smsSenceId,enterpriseId,areaCode, phoneNumber, new String[]{code});
            if(smsSendResult.isSuccess()){
                String key = "GYTCode:" + areaCode + ":" + phoneNumber;
                LoginUserVo userVo = new LoginUserVo();
                userVo.setEnterpriseId(enterpriseId);
                userVo.setAreaCode(areaCode);
                userVo.setCode(code);
                userVo.setPhoneNumber(phoneNumber);
                userVo.setUserId(userDTOList.get(0).getUserId());
                RedisUtil.setCache(key, userVo, 5l, TimeUnit.MINUTES);
                return RestResponse.success(enterpriseId);
            }else {
                return RestResponse.failure(ErrorCode.SYSTEMERROR.getCode(), smsSendResult.getMessage());
            }
        }else {
            return RestResponse.failure(ErrorCode.ACCOUNTNOTEXISTS.getCode(), ErrorCode.ACCOUNTNOTEXISTS.getMsg());
        }
    }

    @RequestMapping("login")
    public RestResponse login(String areaCode, String phoneNumber, String code){
        String key = "GYTCode:" + areaCode + ":" + phoneNumber;
        Object cache = RedisUtil.getCache(key);
        if(cache != null){
            LoginUserVo userVo = (LoginUserVo) cache;
            if(userVo.getCode().equals(code)){
                return RestResponse.success(userVo);
            }else {
                return RestResponse.failure(ErrorCode.SYSTEMERROR.getCode(), "验证码错误");
            }
        }else {
            return RestResponse.failure(ErrorCode.ACCOUNTNOTEXISTS.getCode(), "请发送验证码");
        }
    }
}
